##  Viewing Synchronization Logs
SAP LeanIX generates synchronization logs for each discovery run. You can use the synchronization logs to identify integration issues and get details on each failed integration run.
To access the synchronization logs, do the following:
  1. In the administration area of SAP LeanIX, go to Integrations.
  2. Choose Sync Log.
  3. Use the filters to find AI Agent Discovery in the table.


For more information on synchronization logs, refer to [Synchronization Logging](https://help.sap.com/docs/leanix/ea/synchronization-logging?locale=en-US&state=PRODUCTION&version=CLOUD "Use synchronization logs to track the state of your integrations.").
